@@ -41,6 +41,7 @@ class PropertyConfig(BaseModel):
 class NodeConfig(BaseModel):
     module_path: str = None
     appendix_properties: T.List[str] = []
+    ignore_properties: T.List[str] = []
     basemodel_properties: T.Dict[str, PropertyConfig] = {}
 
 
@@ -372,6 +373,14 @@ def build_node_and_resolver(
         key=lambda x: f"{not x.is_computed}-{x.required}-{x.is_exclusive}-{x.default}",
         reverse=True,
     )
+    # remove ignored properties
+    if node_config:
+        object_type.properties = [
+            p
+            for p in object_type.properties
+            if p.name not in node_config.ignore_properties
+        ]
+
     # start with the properties
     node_resolver_name = f"{object_type.node_name}Resolver"
     property_strs: T.List[str] = []
